@@ -1,7 +1,7 @@
 """Caching to the insane level. File level."""
-from pathlib import Path
 import pickle
 from hashlib import sha256
+from pathlib import Path
 from typing import Any
 
 CACHEDIR = Path(__file__).parent / "__cache__"
@@ -18,7 +18,10 @@ def set(scope: str, key: object, value: object) -> None:
     filename = _hash_key(key) + ".pkl"
     if not (CACHEDIR / scope / filename).is_file():
         (CACHEDIR / scope / filename).touch()
-    (CACHEDIR / scope / filename).write_bytes(pickle.dumps(value))
+    try:
+        (CACHEDIR / scope / filename).write_bytes(pickle.dumps(value))
+    except AttributeError:  # Cannot pickle
+        (CACHEDIR / scope / filename).unlink()
 
 
 def get(scope: str, key: object) -> Any:
