@@ -3,11 +3,11 @@ import enum
 import functools
 import importlib
 import os
-
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, List, Optional, Union, Tuple, Sequence
+from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 
-import selenium.common.exceptions as selenium_exceptions
+from selenium import webdriver as drivers
+import selenium.common.exceptions as browser_exceptions
 from bs4 import BeautifulSoup
 from requests import get, post  # As for API
 from selenium.webdriver.common.by import By
@@ -15,14 +15,17 @@ from selenium.webdriver.remote import webdriver, webelement
 from selenium.webdriver.support import expected_conditions  # As for API
 from selenium.webdriver.support.ui import WebDriverWait  # type: ignore[attr-defined]
 
-from . import internal, _hypercache
+from . import _hypercache, internal
 
+RawWebDriver = webdriver.WebDriver
 __all__ = [
     "get_browser",
     "Browser",
     "BrowserType",
     "BrowserContext",
+    "browser_exceptions",
     "Element",
+    "RawWebDriver",
     "expected_conditions",
     "get",
     "post",
@@ -48,7 +51,7 @@ class BrowserType(enum.Enum):
 
 __get_browser_cache: Dict[
     Tuple[Tuple[BrowserType, ...], bool, Optional[Tuple[str, ...]]],
-    Optional[webdriver.WebDriver],
+    Optional[RawWebDriver],
 ] = {}
 
 
@@ -60,10 +63,11 @@ def get_browser(
     ),
     headless: bool = True,
     arguments: Optional[Sequence[str]] = None,
-) -> webdriver.WebDriver:
+    service_options: Optional[Dict[str, Any]] = None,
+) -> RawWebDriver:
     """Lil' helper function that attempts to get a valid WebDriver"""
     _cache_key = (
-        tuple((enum.name for enum in priority)),
+        tuple(enum.name for enum in priority),
         headless,
         tuple(arguments) if arguments is not None else None,
     )
@@ -72,15 +76,15 @@ def get_browser(
         if output is None:
             raise RuntimeError("Could not find any browser that supports your needs")
         return output
-    try:
-        output = _hypercache.get("web.get_browser", _cache_key)
-        if output is None:
-            raise RuntimeError("Could not find any browser that supports your needs")
-        return output
-    except KeyError:
-        pass
+    # try:
+    #   output = _hypercache.get("web.get_browser", _cache_key)
+    #   if output is None:
+    #       raise RuntimeError("Could not find any browser that supports your needs")
+    #   return output
+    # except KeyError:
+    #   pass
 
-    def _(browser_name: BrowserType) -> Optional[webdriver.WebDriver]:
+    def _(browser_name: BrowserType) -> Optional[RawWebDriver]:
         try:
             options = importlib.import_module(
                 ".options", f"selenium.webdriver.{browser_name.value['name'].lower()}"
@@ -93,18 +97,19 @@ def get_browser(
             if arguments:
                 for arg in arguments:
                     options.add_argument(arg)
+            service = importlib.import_module(
+                ".service",
+                f"selenium.webdriver.{browser_name.value['name'].lower()}",
+            ).Service(log_path=os.devnull, **(service_options or {}))
             browser = functools.partial(
-                getattr(
-                    importlib.import_module(".webdriver", "selenium"),
-                    browser_name.value["name"],
-                ),
+                getattr(drivers, browser_name.value["name"]),
                 options=options,
-                service_log_path=os.devnull,
+                service=service,
             )
             # There is no better way to check validity
             # than to open and close it...
             browser().close()
-        except selenium_exceptions.WebDriverException:
+        except browser_exceptions.WebDriverException:
             return None
         else:
             return browser
@@ -115,7 +120,7 @@ def get_browser(
             _hypercache.set("web.get_browser", _cache_key, found)
             __get_browser_cache[_cache_key] = found
             return found
-    _hypercache.set("web.get_browser", _cache_key, None)
+    # _hypercache.set("web.get_browser", _cache_key, None)
     __get_browser_cache[_cache_key] = None
     # TODO: Download geckodriver and use it
     raise RuntimeError("Could not find any browser that supports your needs")
@@ -169,7 +174,7 @@ class Element:
 @dataclass
 class BrowserContext:
     url: str
-    driver: webdriver.WebDriver
+    driver: RawWebDriver
     _waits: Dict[float, WebDriverWait] = field(default_factory=dict)
 
     def go(self, to: str) -> None:
@@ -250,7 +255,7 @@ class BrowserContext:
 
     def wait(
         self,
-        until: Callable[[webdriver.WebDriver], Union[webelement.WebElement, bool]],
+        until: Callable[[RawWebDriver], Union[webelement.WebElement, bool]],
         up_to: float = 10.0,
     ) -> Element:
         """Wait until an element is located.
@@ -260,7 +265,7 @@ class BrowserContext:
         Raises `TimeoutError` if the element is not found in time.
 
         Args:
-            until (Callable[[webdriver.WebDriver], Union[webelement.WebElement, bool]]):
+            until (Callable[[RawWebDriver], Union[webelement.WebElement, bool]]):
                         An object that when `__call__` is called,
                         return `False` indicating that the element was not found
                         or the `selenium.webdriver.remote` when found.
@@ -276,7 +281,7 @@ class BrowserContext:
         """
         try:
             return Element(self._get_wait_up_to(up_to).until(until))
-        except selenium_exceptions.TimeoutException as error:
+        except browser_exceptions.TimeoutException as error:
             raise TimeoutError(
                 f"Could not find element under {up_to} seconds"
             ) from error
@@ -299,9 +304,7 @@ class Browser(contextlib.AbstractContextManager):
     """
 
     url: str
-    # pylint: disable=unnecessary-lambda
-    # No, we need that lambda for lazy loading
-    driver: Callable[[], webdriver.WebDriver] = field(default_factory=get_browser)
+    driver: Callable[[], RawWebDriver] = field(default_factory=get_browser)
 
     def open(self) -> BrowserContext:
         """Start the browser"""
@@ -311,7 +314,7 @@ class Browser(contextlib.AbstractContextManager):
             try:
                 self.driver.get(self.url)
                 break
-            except selenium_exceptions.WebDriverException:
+            except browser_exceptions.WebDriverException:
                 tries -= 1
                 continue
         if tries == 0:
